@@ -14,9 +14,11 @@ Use 'gas ls' to list data.
 
 Use 'gas draft' to operate a draft.
 
+Use 'gas branch' to operate a branch.
+
 """
 
-from typing import Any, Dict, Iterable, Optional
+from typing import Any, Dict, Iterable, Optional, Tuple
 
 import click
 
@@ -175,21 +177,21 @@ def ls(  # pylint: disable=invalid-name
 
 
 @cli.command()
-@click.argument("access_key", type=str, default="")
-@click.argument("url", type=str, default="", metavar="")
+@click.argument("arg1", type=str, default="", metavar="[accessKey or 'editor']")
+@click.argument("arg2", type=str, default="", metavar="[editor name]")
 @click.pass_obj
-def config(obj: Dict[str, str], access_key: str, url: str) -> None:
-    """Configure the accessKey of gas.\f
+def config(obj: Dict[str, str], arg1: str, arg2: str) -> None:
+    """Configure the accessKey of gas or the editor to be launched when using gas.\f
 
     Arguments:
         obj: A dict contains config information.
-        access_key: The accessKey of gas to write into config file.
-        url: The URL of gas to write into config file.
+        arg1: The accessKey of gas to write into config file or the keyword "editor".
+        arg2: The URL of gas to write into config file or the editor to be lanched.
 
     """  # noqa: D301,D415
     from .config import _implement_config
 
-    _implement_config(obj, access_key, url)
+    _implement_config(obj, arg1, arg2)
 
 
 @cli.command()
@@ -239,9 +241,11 @@ def draft(
 
 @cli.command()
 @click.argument("tbrn", type=str)
-@click.option("-m", "--message", type=str, required=True, help="The message of the commit.")
+@click.option(
+    "-m", "--message", type=str, multiple=True, default=(), help="The message of the commit."
+)
 @click.pass_obj
-def commit(obj: Dict[str, str], tbrn: str, message: str) -> None:
+def commit(obj: Dict[str, str], tbrn: str, message: Tuple[str, ...]) -> None:
     """Work with commit.\f
 
     Arguments:
@@ -316,5 +320,74 @@ def rm(  # pylint: disable=invalid-name, too-many-arguments
     _implement_rm(obj, tbrn, is_recursive)
 
 
+@cli.command()
+@click.argument("tbrn", type=str)
+@click.argument("name", type=str, default="")
+@click.option("-v", "--verbose", is_flag=True, help="Show short commit id and commit message.")
+@click.option("-d", "--delete", "is_delete", is_flag=True, help="Delete the branch")
+@click.pass_obj
+def branch(obj: Dict[str, str], tbrn: str, name: str, verbose: bool, is_delete: bool) -> None:
+    """Work with branch.\f
+
+    Arguments:
+        obj: A dict contains config information.
+        tbrn: The tbrn of the dataset.
+        name: The name of the branch to be created.
+        verbose: Whether to show the short commit id and commit message.
+        is_delete: Whether to delete the branch.
+
+    """  # noqa: D301,D415
+    from .branch import _implement_branch
+
+    _implement_branch(obj, tbrn, name, verbose, is_delete)
+
+
+@cli.command()
+@click.argument("tbrn", type=str)
+@click.argument("name", type=str, default="")
+@click.option("-d", "--delete", "is_delete", is_flag=True, help="Delete the tag.")
+@click.pass_obj
+def tag(obj: Dict[str, str], tbrn: str, name: str, is_delete: bool) -> None:
+    """Work with tag.\f
+
+    Arguments:
+        obj: A dict contains config information.
+        tbrn: The tbrn of the dataset.
+        name: The name of the tag.
+        is_delete: Whether to delete the tag.
+
+    """  # noqa: D301,D415
+    from .tag import _implement_tag
+
+    _implement_tag(obj, tbrn, name, is_delete)
+
+
+@cli.command()
+@click.argument("tbrn", type=str)
+@click.option(
+    "-n", "--max-count", type=int, default=None, help="Limit the max number of commits to be showed"
+)
+@click.option("--oneline", is_flag=True, help="Limit commit message to oneline")
+@click.pass_obj
+def log(
+    obj: Dict[str, str],
+    tbrn: str,
+    max_count: Optional[int],
+    oneline: bool,
+) -> None:
+    """Show commit logs.\f
+
+    Arguments:
+        obj: A dict contains config information.
+        tbrn: The tbrn of a dataset.
+        max_count: Max number of commits to show.
+        oneline: Whether to show a commit message in oneline.
+
+    """  # noqa: D301,D415
+    from .log import _implement_log
+
+    _implement_log(obj, tbrn, max_count, oneline)
+
+
 if __name__ == "__main__":
     cli()  # pylint: disable=no-value-for-parameter
