@@ -5,26 +5,23 @@
 
 """Implementation of gas dataset."""
 
-import sys
 from typing import Dict
 
 import click
 
 from .tbrn import TBRN, TBRNType
-from .utility import get_gas
+from .utility import error, get_gas
 
 
 def _implement_dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
     gas = get_gas(**obj)
     if is_delete:
         if not tbrn:
-            click.echo("Missing argument TBRN", err=True)
-            sys.exit(1)
+            error("Missing argument TBRN")
 
         info = TBRN(tbrn=tbrn)
         if info.type != TBRNType.DATASET:
-            click.echo(f'"{tbrn}" is not a dataset', err=True)
-            sys.exit(1)
+            error(f'"{tbrn}" is not a dataset')
 
         if not yes:
             click.confirm(
@@ -39,8 +36,7 @@ def _implement_dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: boo
     if tbrn:
         info = TBRN(tbrn=tbrn)
         if info.type != TBRNType.DATASET:
-            click.echo(f'"{tbrn}" is not a dataset', err=True)
-            sys.exit(1)
+            error(f'"{tbrn}" is not a dataset')
 
         gas.create_dataset(info.dataset_name)
         click.echo(f'Dataset "{tbrn}" is created successfully')
