@@ -22,21 +22,30 @@ Please refer to :class:`~tensorbay.dataset.dataset.FusionDataset` for more infor
 
 """
 
-import sys
+import logging
 from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Iterator, Optional, Tuple, Union
 
 from ..dataset import Data, Frame, FusionSegment, Notes, Segment
-from ..exception import FrameError, NameConflictError, ResourceNotExistError
+from ..exception import (
+    FrameError,
+    NameConflictError,
+    OperationError,
+    ResourceNotExistError,
+    StatusError,
+)
 from ..label import Catalog
-from ..utility import Deprecated, KwargsDeprecated
-from .commit_status import CommitStatus
+from ..utility import DefaultValueDeprecated
+from .log import UPLOAD_SEGMENT_RESUME_TEMPLATE
 from .requests import Client, PagingList, Tqdm, multithread_upload
 from .segment import FusionSegmentClient, SegmentClient
+from .status import Status
 from .struct import Branch, Commit, Draft, Tag
 
 if TYPE_CHECKING:
     from .gas import GAS
 
+logger = logging.getLogger(__name__)
+
 
 class DatasetClientBase:  # pylint: disable=too-many-public-methods
     """This class defines the basic concept of the dataset client.
@@ -60,36 +69,35 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
     _client: Client
 
-    def __init__(
-        self, name: str, dataset_id: str, gas_client: "GAS", *, commit_id: Optional[str] = None
-    ) -> None:
+    def __init__(self, name: str, dataset_id: str, gas_client: "GAS", *, status: Status) -> None:
         self._name = name
         self._dataset_id = dataset_id
         self._gas_client = gas_client
         self._client = gas_client._client  # pylint: disable=protected-access
+        self._status = status
 
-        self._status = CommitStatus()
-        if commit_id:
-            self._status.checkout(commit_id=commit_id)
-
-    def _commit(self, message: str, tag: Optional[str] = None) -> str:
-        post_data: Dict[str, Any] = {
-            "message": message,
-        }
+    def _commit(self, title: str, description: str, tag: Optional[str] = None) -> str:
+        post_data: Dict[str, Any] = {"title": title}
         post_data.update(self._status.get_status_info())
 
+        if description:
+            post_data["description"] = description
+
         if tag:
             post_data["tag"] = tag
 
         response = self._client.open_api_do("POST", "commits", self.dataset_id, json=post_data)
         return response.json()["commitId"]  # type: ignore[no-any-return]
 
-    def _create_draft(self, title: Optional[str] = None) -> int:
+    def _create_draft(self, title: Optional[str], branch_name: Optional[str] = None) -> int:
         post_data: Dict[str, Any] = {}
 
         if title:
             post_data["title"] = title
 
+        if branch_name:
+            post_data["branchName"] = branch_name
+
         response = self._client.open_api_do("POST", "drafts", self.dataset_id, json=post_data)
         return response.json()["draftNumber"]  # type: ignore[no-any-return]
 
@@ -170,6 +178,17 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _delete_branch(self, name: str) -> None:
+        """Delete a branch without checking current branch.
+
+        Arguments:
+            name: The name of the branch to be deleted.
+
+        """
+        delete_data: Dict[str, Any] = {"name": name}
+
+        self._client.open_api_do("DELETE", "branches", self.dataset_id, json=delete_data)
+
     @property
     def name(self) -> str:
         """Return the TensorBay dataset name.
@@ -191,7 +210,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         return self._dataset_id
 
     @property
-    def status(self) -> CommitStatus:
+    def status(self) -> Status:
         """Return the status of the dataset client.
 
         Returns:
@@ -200,24 +219,44 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         """
         return self._status
 
-    def create_draft(self, title: Optional[str] = None) -> int:
-        """Create the draft.
+    @DefaultValueDeprecated("title", since="v1.6.0", removed_in="v1.9.0")
+    def create_draft(self, title: Optional[str] = None, branch_name: Optional[str] = None) -> int:
+        """Create a draft.
+
+        Create a draft with the branch name. If the branch name is not given,
+        create a draft based on the branch name stored in the dataset client.
+        Then the dataset client will change the status to "draft"
+        and store the branch name and draft number.
 
         Arguments:
             title: The draft title.
+            branch_name: The branch name.
 
         Returns:
             The draft number of the created draft.
 
+        Raises:
+            StatusError: When creating the draft without basing on a branch.
+
         """
-        self._status.check_authority_for_commit()
-        draft_number = self._create_draft(title)
+        if not branch_name:
+            if not self.status.branch_name:
+                raise StatusError(
+                    message="Creating the draft without basing on a branch is not allowed"
+                )
+            branch_name = self.status.branch_name
+            self._status.check_authority_for_commit()
+        draft_number = self._create_draft(title, branch_name)
         self._status.checkout(draft_number=draft_number)
+        self._status.branch_name = branch_name
         return draft_number
 
     def get_draft(self, draft_number: Optional[int] = None) -> Draft:
         """Get the certain draft with the given draft number.
 
+        Get the certain draft with the given draft number. If the draft number is not given,
+        get the draft based on the draft number stored in the dataset client.
+
         Arguments:
             draft_number: The required draft number.
                 If is not given, get the current draft.
@@ -243,51 +282,21 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         raise ResourceNotExistError(resource="draft", identification=draft_number)
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_drafts(self, **kwargs: int) -> PagingList[Draft]:
+    def list_drafts(self) -> PagingList[Draft]:
         """List all the drafts.
 
-        Arguments:
-            kwargs: For deprecated keyword arguments: "start" and "stop".
-
         Returns:
             The PagingList of :class:`drafts<.Draft>`.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
-
-        paging_list = PagingList(self._generate_drafts, 128)
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
-
-        return paging_list
-
-    @Deprecated(since="1.2.0", removed_in="1.5.0", substitute=list_drafts)
-    def list_draft_titles_and_numbers(
-        self, *, start: int = 0, stop: int = sys.maxsize
-    ) -> Iterator[Dict[str, Any]]:
-        """List the dict containing title and number of drafts.
-
-        Arguments:
-            start: The index to start.
-            stop: The index to end.
-
-        Yields:
-            The dict containing title and number of drafts.
-
-        """
-        for draft in self.list_drafts(start=start, stop=stop):
-            yield draft.dumps()
+        return PagingList(self._generate_drafts, 128)
 
     def get_commit(self, revision: Optional[str] = None) -> Commit:
         """Get the certain commit with the given revision.
 
+        Get the certain commit with the given revision. If the revision is not given,
+        get the commit based on the commit id stored in the dataset client.
+
         Arguments:
             revision: The information to locate the specific commit, which can be the commit id,
                 the branch name, or the tag name.
@@ -315,13 +324,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         return commit
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_commits(self, revision: Optional[str] = None, **kwargs: int) -> PagingList[Commit]:
+    def list_commits(self, revision: Optional[str] = None) -> PagingList[Commit]:
         """List the commits.
 
         Arguments:
@@ -329,25 +332,20 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
                 the branch name, or the tag name.
                 If is given, list the commits before the given commit.
                 If is not given, list the commits before the current commit.
-            kwargs: For deprecated keyword arguments: "start" and "stop".
 
         Returns:
             The PagingList of :class:`commits<.Commit>`.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
-
-        paging_list = PagingList(
+        return PagingList(
             lambda offset, limit: self._generate_commits(revision, offset, limit), 128
         )
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
-
-        return paging_list
 
     def create_tag(self, name: str, revision: Optional[str] = None) -> None:
-        """Create the tag for a commit.
+        """Create a tag for a commit.
+
+        Create a tag for a commit with the given revision. If the revision is not given,
+        create a tag based on the commit id stored in the dataset client.
 
         Arguments:
             name: The tag name to be created for the specific commit.
@@ -388,32 +386,40 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         return tag
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_tags(self, **kwargs: int) -> PagingList[Tag]:
+    def list_tags(self) -> PagingList[Tag]:
         """List the information of tags.
 
-        Arguments:
-            kwargs: For deprecated keyword arguments: "start" and "stop".
-
         Returns:
             The PagingList of :class:`tags<.Tag>`.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
+        return PagingList(lambda offset, limit: self._generate_tags(None, offset, limit), 128)
 
-        paging_list = PagingList(
-            lambda offset, limit: self._generate_tags(None, offset, limit), 128
-        )
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
+    def create_branch(self, name: str, revision: Optional[str] = None) -> None:
+        """Create a branch.
 
-        return paging_list
+        Create a branch based on a commit with the given revision. If the revision is not given,
+        create a branch based on the commit id stored in the dataset client.
+        Then the dataset client will change the status to "commit"
+        and store the branch name and the commit id.
+
+        Arguments:
+            name: The branch name.
+            revision: The information to locate the specific commit, which can be the commit id,
+                the branch name, or the tag name.
+                If the revision is not given, create the branch based on the current commit.
+
+        """
+        if not revision:
+            self._status.check_authority_for_commit()
+        else:
+            self.checkout(revision=revision)
+        revision = self._status.commit_id
+
+        post_data: Dict[str, Any] = {"name": name, "commit": revision}
+        self._client.open_api_do("POST", "branches", self.dataset_id, json=post_data)
+
+        self._status.branch_name = name
 
     def get_branch(self, name: str) -> Branch:
         """Get the branch with the given name.
@@ -439,32 +445,32 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         return branch
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_branches(self, **kwargs: int) -> PagingList[Branch]:
+    def list_branches(self) -> PagingList[Branch]:
         """List the information of branches.
 
-        Arguments:
-            kwargs: For deprecated keyword arguments: "start" and "stop".
-
         Returns:
             The PagingList of :class:`branches<.Branch>`.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
-        paging_list = PagingList(
-            lambda offset, limit: self._generate_branches(None, offset, limit),
-            128,
-        )
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
+        return PagingList(lambda offset, limit: self._generate_branches(None, offset, limit), 128)
 
-        return paging_list
+    def delete_branch(self, name: str) -> None:
+        """Delete a branch.
+
+        Delete the branch with the given branch name. Note that deleting the branch with the name
+        which is stored in the current dataset client is not allowed.
+
+        Arguments:
+            name: The name of the branch to be deleted.
+
+        Raises:
+            OperationError: When deleting the current branch.
+
+        """
+        if name == self.status.branch_name:
+            raise OperationError("Deleting the current branch is not allowed")
+
+        self._delete_branch(name)
 
     def checkout(self, revision: Optional[str] = None, draft_number: Optional[int] = None) -> None:
         """Checkout to commit or draft.
@@ -484,23 +490,34 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
             raise TypeError("Both revision and draft number are given, please only give one")
 
         if revision:
-            commit_id = self.get_commit(revision).commit_id
-            self._status.checkout(commit_id=commit_id)
+            try:
+                branch = self.get_branch(revision)
+                self._status.checkout(commit_id=branch.commit_id)
+                self._status.branch_name = branch.name
+            except ResourceNotExistError:
+                self._status.checkout(commit_id=self.get_commit(revision).commit_id)
+                self._status.branch_name = None
 
         if draft_number:
-            draft_number = self.get_draft(draft_number).number
-            self._status.checkout(draft_number=draft_number)
+            draft = self.get_draft(draft_number)
+            self._status.checkout(draft_number=draft.number)
+            self._status.branch_name = draft.branch_name
 
-    def commit(self, message: str, *, tag: Optional[str] = None) -> None:
+    def commit(self, title: str, description: str = "", *, tag: Optional[str] = None) -> None:
         """Commit the draft.
 
+        Commit the draft based on the draft number stored in the dataset client.
+        Then the dataset client will change the status to "commit"
+        and store the branch name and commit id.
+
         Arguments:
-            message: The commit message.
+            title: The commit title.
+            description: The commit description.
             tag: A tag for current commit.
 
         """
         self._status.check_authority_for_draft()
-        self._status.checkout(commit_id=self._commit(message, tag))
+        self._status.checkout(commit_id=self._commit(title, description, tag))
 
     def update_notes(
         self,
@@ -543,30 +560,14 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
             self._client.open_api_do("GET", "notes", self.dataset_id, params=params).json()
         )
 
-    @KwargsDeprecated(
-        ("start", "stop"),
-        since="1.3.0",
-        removed_in="1.5.0",
-        substitute="PagingList[start:stop]",
-    )
-    def list_segment_names(self, **kwargs: int) -> PagingList[str]:
+    def list_segment_names(self) -> PagingList[str]:
         """List all segment names in a certain commit.
 
-        Arguments:
-            kwargs: For deprecated keyword arguments: "start" and "stop".
-
         Returns:
             The PagingList of segment names.
 
         """
-        start = kwargs.get("start")
-        stop = kwargs.get("stop")
-
-        paging_list = PagingList(self._generate_segment_names, 128)
-        if start is not None or stop is not None:
-            return paging_list[start:stop]
-
-        return paging_list
+        return PagingList(self._generate_segment_names, 128)
 
     def get_catalog(self) -> Catalog:
         """Get the catalog of the certain commit.
@@ -682,11 +683,11 @@ class DatasetClient(DatasetClientBase):
 
         return segment_client
 
-    def get_or_create_segment(self, name: str = "") -> SegmentClient:
+    def get_or_create_segment(self, name: str = "default") -> SegmentClient:
         """Get or create a segment with the given name.
 
         Arguments:
-            name: Segment name, can not be "_default".
+            name: The name of the fusion segment.
 
         Returns:
             The created :class:`~tensorbay.client.segment.SegmentClient` with given name.
@@ -697,11 +698,11 @@ class DatasetClient(DatasetClientBase):
             self._create_segment(name)
         return SegmentClient(name, self)
 
-    def create_segment(self, name: str = "") -> SegmentClient:
+    def create_segment(self, name: str = "default") -> SegmentClient:
         """Create a segment with the given name.
 
         Arguments:
-            name: Segment name, can not be "_default".
+            name: The name of the fusion segment.
 
         Returns:
             The created :class:`~tensorbay.client.segment.SegmentClient` with given name.
@@ -717,7 +718,7 @@ class DatasetClient(DatasetClientBase):
             raise NameConflictError(resource="segment", identification=name)
         return SegmentClient(name, self)
 
-    def get_segment(self, name: str = "") -> SegmentClient:
+    def get_segment(self, name: str = "default") -> SegmentClient:
         """Get a segment in a certain commit according to given name.
 
         Arguments:
@@ -758,16 +759,27 @@ class DatasetClient(DatasetClientBase):
             skip_uploaded_files: True for skipping the uploaded files.
             quiet: Set to True to stop showing the upload process bar.
 
+        Raises:
+            Exception: When the upload got interrupted by Exception.
+
         Returns:
             The :class:`~tensorbay.client.segment.SegmentClient`
             used for uploading the data in the segment.
 
         """
         self._status.check_authority_for_draft()
-        with Tqdm(len(segment), disable=quiet) as pbar:
-            return self._upload_segment(
-                segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
+        try:
+            with Tqdm(len(segment), disable=quiet) as pbar:
+                return self._upload_segment(
+                    segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
+                )
+        except Exception:
+            logger.error(
+                UPLOAD_SEGMENT_RESUME_TEMPLATE,
+                self._status.draft_number,
+                self._status.draft_number,
             )
+            raise
 
 
 class FusionDatasetClient(DatasetClientBase):
@@ -785,10 +797,10 @@ class FusionDatasetClient(DatasetClientBase):
 
     @staticmethod
     def _skip_upload_frame(
-        segment_filter: Iterator[Tuple[Frame, Optional[int], bool]],
+        segment_filter: Iterator[Tuple[Frame, Optional[float], bool]],
         done_set: Dict[float, Frame],
         pbar: Tqdm,
-    ) -> Iterator[Tuple[Frame, Optional[int], bool]]:
+    ) -> Iterator[Tuple[Frame, Optional[float], bool]]:
         for frame, timestamp, _ in segment_filter:
             if timestamp is None:
                 timestamp = frame.frame_id.timestamp().timestamp
@@ -830,7 +842,7 @@ class FusionDatasetClient(DatasetClientBase):
         for sensor in segment.sensors.values():
             segment_client.upload_sensor(sensor)
 
-        segment_filter: Iterator[Tuple[Frame, Optional[int], bool]]
+        segment_filter: Iterator[Tuple[Frame, Optional[float], bool]]
 
         if not segment:
             return segment_client
@@ -866,11 +878,11 @@ class FusionDatasetClient(DatasetClientBase):
 
         return segment_client
 
-    def get_or_create_segment(self, name: str = "") -> FusionSegmentClient:
+    def get_or_create_segment(self, name: str = "default") -> FusionSegmentClient:
         """Get or create a fusion segment with the given name.
 
         Arguments:
-            name: Segment name, can not be "_default".
+            name: The name of the fusion segment.
 
         Returns:
             The created :class:`~tensorbay.client.segment.FusionSegmentClient` with given name.
@@ -881,11 +893,11 @@ class FusionDatasetClient(DatasetClientBase):
             self._create_segment(name)
         return FusionSegmentClient(name, self)
 
-    def create_segment(self, name: str = "") -> FusionSegmentClient:
+    def create_segment(self, name: str = "default") -> FusionSegmentClient:
         """Create a fusion segment with the given name.
 
         Arguments:
-            name: Segment name, can not be "_default".
+            name: The name of the fusion segment.
 
         Returns:
             The created :class:`~tensorbay.client.segment.FusionSegmentClient` with given name.
@@ -901,7 +913,7 @@ class FusionDatasetClient(DatasetClientBase):
             raise NameConflictError(resource="segment", identification=name)
         return FusionSegmentClient(name, self)
 
-    def get_segment(self, name: str = "") -> FusionSegmentClient:
+    def get_segment(self, name: str = "default") -> FusionSegmentClient:
         """Get a fusion segment in a certain commit according to given name.
 
         Arguments:
@@ -941,13 +953,24 @@ class FusionDatasetClient(DatasetClientBase):
             skip_uploaded_files: Set it to True to skip the uploaded files.
             quiet: Set to True to stop showing the upload process bar.
 
+        Raises:
+            Exception: When the upload got interrupted by Exception.
+
         Returns:
             The :class:`~tensorbay.client.segment.FusionSegmentClient`
                 used for uploading the data in the segment.
 
         """
         self._status.check_authority_for_draft()
-        with Tqdm(len(segment), disable=quiet) as pbar:
-            return self._upload_segment(
-                segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
+        try:
+            with Tqdm(len(segment), disable=quiet) as pbar:
+                return self._upload_segment(
+                    segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
+                )
+        except Exception:
+            logger.error(
+                UPLOAD_SEGMENT_RESUME_TEMPLATE,
+                self._status.draft_number,
+                self._status.draft_number,
             )
+            raise
