@@ -19,15 +19,19 @@ from typing import Any, Dict, Generator, Optional, Type, Union, overload
 from typing_extensions import Literal
 
 from ..dataset import Dataset, FusionDataset
-from ..exception import DatasetTypeError, ResourceNotExistError
+from ..exception import DatasetTypeError, OperationError, ResourceNotExistError
 from .dataset import DatasetClient, FusionDatasetClient
 from .log import UPLOAD_DATASET_RESUME_TEMPLATE
 from .requests import Client, PagingList, Tqdm
+from .status import Status
+from .struct import ROOT_COMMIT_ID
 
 DatasetClientType = Union[DatasetClient, FusionDatasetClient]
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_BRANCH = "main"
+
 
 class GAS:
     """:class:`GAS` defines the initial client to interact between local and TensorBay.
@@ -61,9 +65,13 @@ class GAS:
         info = self._get_dataset(name)
         dataset_id = info["id"]
         is_fusion = info["type"]
-        commit_id = info["HEAD"]["commitId"]
+        commit_id = info["commitId"]
+        default_branch = info["defaultBranch"]
+
+        status = Status(default_branch, commit_id=commit_id)
+
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self, commit_id=commit_id)
+        return ReturnType(name, dataset_id, self, status=status)
 
     def _get_dataset(self, name: str) -> Dict[str, Any]:
         """Get the information of the TensorBay dataset with the input name.
@@ -87,12 +95,14 @@ class GAS:
         except IndexError as error:
             raise ResourceNotExistError(resource="dataset", identification=name) from error
 
-        return info  # type: ignore[no-any-return]
+        dataset_id = info["id"]
+        response = self._client.open_api_do("GET", "", dataset_id).json()
+        response["id"] = dataset_id
+        return response
 
     def _list_datasets(
         self,
         name: Optional[str] = None,
-        need_team_dataset: bool = False,  # personal: False, all: True
         offset: int = 0,
         limit: int = 128,
     ) -> Dict[str, Any]:
@@ -102,8 +112,6 @@ class GAS:
         }
         if name:
             params["name"] = name
-        if need_team_dataset:
-            params["needTeamDataset"] = need_team_dataset
 
         response = self._client.open_api_do("GET", "", params=params)
         return response.json()  # type: ignore[no-any-return]
@@ -111,11 +119,10 @@ class GAS:
     def _generate_dataset_names(
         self,
         name: Optional[str] = None,
-        need_team_dataset: bool = False,  # personal: False, all: True
         offset: int = 0,
         limit: int = 128,
     ) -> Generator[str, None, int]:
-        response = self._list_datasets(name, need_team_dataset, offset, limit)
+        response = self._list_datasets(name, offset, limit)
 
         for item in response["datasets"]:
             yield item["name"]
@@ -218,9 +225,11 @@ class GAS:
         if region:
             post_data["region"] = region
 
+        status = Status(DEFAULT_BRANCH, commit_id=ROOT_COMMIT_ID)
+
         response = self._client.open_api_do("POST", "", json=post_data)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, response.json()["id"], self)
+        return ReturnType(name, response.json()["id"], self, status=status)
 
     def create_auth_dataset(
         self, name: str, config_name: str, path: str, is_fusion: bool = False
@@ -247,9 +256,12 @@ class GAS:
             "type": int(is_fusion),  # normal dataset: 0, fusion dataset: 1
             "storageConfig": {"name": config_name, "path": path},
         }
+
+        status = Status(DEFAULT_BRANCH, commit_id=ROOT_COMMIT_ID)
+
         response = self._client.open_api_do("POST", "", json=post_data)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, response.json()["id"], self)
+        return ReturnType(name, response.json()["id"], self, status=status)
 
     @overload
     def get_dataset(self, name: str, is_fusion: Literal[False] = False) -> DatasetClient:
@@ -283,12 +295,15 @@ class GAS:
 
         dataset_id = info["id"]
         type_flag = info["type"]
-        commit_id = info["HEAD"]["commitId"]
+        commit_id = info["commitId"]
+        default_branch = info["defaultBranch"]
+
+        status = Status(default_branch, commit_id=commit_id)
 
         if is_fusion != type_flag:
             raise DatasetTypeError(name, type_flag)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self, commit_id=commit_id)
+        return ReturnType(name, dataset_id, self, status=status)
 
     def list_dataset_names(self) -> PagingList[str]:
         """List names of all TensorBay datasets.
@@ -298,7 +313,7 @@ class GAS:
 
         """
         return PagingList(
-            lambda offset, limit: self._generate_dataset_names(None, False, offset, limit), 128
+            lambda offset, limit: self._generate_dataset_names(None, offset, limit), 128
         )
 
     def rename_dataset(self, name: str, new_name: str) -> None:
@@ -319,6 +334,7 @@ class GAS:
         dataset: Dataset,
         draft_number: Optional[int] = None,
         *,
+        branch_name: Optional[str] = None,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
         quiet: bool = False,
@@ -331,6 +347,7 @@ class GAS:
         dataset: FusionDataset,
         draft_number: Optional[int] = None,
         *,
+        branch_name: Optional[str] = None,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
         quiet: bool = False,
@@ -343,6 +360,7 @@ class GAS:
         dataset: Union[Dataset, FusionDataset],
         draft_number: Optional[int] = None,
         *,
+        branch_name: Optional[str] = None,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
         quiet: bool = False,
@@ -354,6 +372,7 @@ class GAS:
         dataset: Union[Dataset, FusionDataset],
         draft_number: Optional[int] = None,
         *,
+        branch_name: Optional[str] = None,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
         quiet: bool = False,
@@ -371,9 +390,10 @@ class GAS:
         Arguments:
             dataset: The :class:`~tensorbay.dataset.dataset.Dataset` or
                 :class:`~tensorbay.dataset.dataset. FusionDataset` needs to be uploaded.
+            draft_number: The draft number.
+            branch_name: The branch name.
             jobs: The number of the max workers in multi-thread upload.
             skip_uploaded_files: Set it to True to skip the uploaded files.
-            draft_number: The draft number.
             quiet: Set to True to stop showing the upload process bar.
 
         Returns:
@@ -382,14 +402,32 @@ class GAS:
             bound with the uploaded dataset.
 
         Raises:
-            Exception: When Exception was raised during uploding dataset.
+            OperationError: When uploading the dataset based on both draft number
+                and branch name is not allowed.
+            Exception: When Exception was raised during uploading dataset.
 
         """
         dataset_client = self.get_dataset(dataset.name, isinstance(dataset, FusionDataset))
+
+        if draft_number and branch_name:
+            raise OperationError(
+                "Uploading the dataset based on both draft number and branch name is not allowed"
+            )
+
         if draft_number:
             dataset_client.checkout(draft_number=draft_number)
+
         else:
-            dataset_client.create_draft()
+            target_branch_name = branch_name if branch_name else dataset_client.status.branch_name
+
+            for draft in dataset_client.list_drafts():
+                if draft.branch_name == target_branch_name:
+                    dataset_client.checkout(draft_number=draft.number)
+                    break
+            else:
+                dataset_client.create_draft(
+                    'Draft autogenerated by "GAS.upload_dataset"', branch_name=target_branch_name
+                )
 
         try:
             if dataset.catalog:
@@ -406,11 +444,12 @@ class GAS:
                         pbar=pbar,
                     )
         except Exception:
-            logger.error(
-                UPLOAD_DATASET_RESUME_TEMPLATE,
-                dataset_client.status.draft_number,
-                dataset_client.status.draft_number,
-            )
+            if draft_number:
+                logger.error(
+                    UPLOAD_DATASET_RESUME_TEMPLATE,
+                    dataset_client.status.draft_number,
+                    dataset_client.status.draft_number,
+                )
             raise
 
         return dataset_client
