@@ -17,12 +17,15 @@
 
 """
 
+from functools import partial
 from typing import Any, Dict, Optional, Tuple, Type, TypeVar
 
-from ..utility import EqMixin, ReprMixin, common_loads
+from ..utility import AttrsMixin, ReprMixin, attr, camel, common_loads
+
+ROOT_COMMIT_ID = "00000000000000000000000000000000"
 
 
-class User(ReprMixin, EqMixin):
+class User(AttrsMixin, ReprMixin):
     """This class defines the basic concept of a user with an action.
 
     Arguments:
@@ -35,6 +38,9 @@ class User(ReprMixin, EqMixin):
 
     _repr_attrs = ("date",)
 
+    name: str = attr()
+    date: int = attr()
+
     def __init__(self, name: str, date: int) -> None:
         self.name = name
         self.date = date
@@ -42,10 +48,6 @@ class User(ReprMixin, EqMixin):
     def _repr_head(self) -> str:
         return f'{self.__class__.__name__}("{self.name}")'
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self.name = contents["name"]
-        self.date = contents["date"]
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a :class:`User` instance from the given contents.
@@ -76,46 +78,49 @@ class User(ReprMixin, EqMixin):
                 }
 
         """
-        return {"name": self.name, "date": self.date}
+        return self._dumps()
 
 
-class Commit(ReprMixin, EqMixin):
+class Commit(AttrsMixin, ReprMixin):
     """This class defines the structure of a commit.
 
     Arguments:
         commit_id: The commit id.
         parent_commit_id: The parent commit id.
-        message: The commit message.
+        title: The commit title.
+        description: The commit description.
         committer: The commit user.
 
     """
 
     _T = TypeVar("_T", bound="Commit")
 
-    _repr_attrs: Tuple[str, ...] = ("parent_commit_id", "message", "committer")
+    _repr_attrs: Tuple[str, ...] = ("parent_commit_id", "title", "description", "committer")
     _repr_maxlevel = 2
 
-    def __init__(
+    commit_id: str = attr(key=camel)
+    parent_commit_id: Optional[str] = attr(key=camel)
+    title: str = attr()
+    description: str = attr(default="")
+    committer: User = attr()
+
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         commit_id: str,
         parent_commit_id: Optional[str],
-        message: str,
+        title: str,
+        description: str,
         committer: User,
     ) -> None:
         self.commit_id = commit_id
         self.parent_commit_id = parent_commit_id
-        self.message = message
+        self.title = title
+        self.description = description
         self.committer = committer
 
     def _repr_head(self) -> str:
         return f'{self.__class__.__name__}("{self.commit_id}")'
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self.commit_id = contents["commitId"]
-        self.parent_commit_id = contents["parentCommitId"]
-        self.message = contents["message"]
-        self.committer = User.loads(contents["committer"])
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a :class:`Commit` instance for the given contents.
@@ -126,7 +131,8 @@ class Commit(ReprMixin, EqMixin):
                     {
                         "commitId": <str>
                         "parentCommitId": <str> or None
-                        "message": <str>
+                        "title": <str>
+                        "description": <str>
                         "committer": {
                             "name": <str>
                             "date": <int>
@@ -148,7 +154,8 @@ class Commit(ReprMixin, EqMixin):
                 {
                     "commitId": <str>
                     "parentCommitId": <str> or None
-                    "message": <str>
+                    "title": <str>
+                    "description": <str>
                     "committer": {
                         "name": <str>
                         "date": <int>
@@ -156,12 +163,7 @@ class Commit(ReprMixin, EqMixin):
                 }
 
         """
-        return {
-            "commitId": self.commit_id,
-            "parentCommitId": self.parent_commit_id,
-            "message": self.message,
-            "committer": self.committer.dumps(),
-        }
+        return self._dumps()
 
 
 class _NamedCommit(Commit):
@@ -173,7 +175,8 @@ class _NamedCommit(Commit):
         name: The name of the named commit.
         commit_id: The commit id.
         parent_commit_id: The parent commit id.
-        message: The commit message.
+        title: The commit title.
+        description: The commit description.
         committer: The commit user.
 
     """
@@ -182,24 +185,23 @@ class _NamedCommit(Commit):
 
     _repr_attrs = ("commit_id",) + Commit._repr_attrs
 
+    name: str = attr()
+
     def __init__(  # pylint: disable=too-many-arguments
         self,
         name: str,
         commit_id: str,
         parent_commit_id: Optional[str],
-        message: str,
+        title: str,
+        description: str,
         committer: User,
     ) -> None:
-        super().__init__(commit_id, parent_commit_id, message, committer)
+        super().__init__(commit_id, parent_commit_id, title, description, committer)
         self.name = name
 
     def _repr_head(self) -> str:
         return f'{self.__class__.__name__}("{self.name}")'
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        super()._loads(contents)
-        self.name = contents["name"]
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a :class:`_NamedCommit` instance for the given contents.
@@ -211,7 +213,8 @@ class _NamedCommit(Commit):
                         "name": <str>
                         "commitId": <str>
                         "parentCommitId": <str> or None
-                        "message": <str>
+                        "title": <str>
+                        "description": <str>
                         "committer": {
                             "name": <str>
                             "date": <int>
@@ -234,7 +237,8 @@ class _NamedCommit(Commit):
                     "name": <str>
                     "commitId": <str>
                     "parentCommitId": <str> or None
-                    "message": <str>
+                    "title": <str>
+                    "description": <str>
                     "committer": {
                         "name": <str>
                         "date": <int>
@@ -242,9 +246,7 @@ class _NamedCommit(Commit):
                 }
 
         """
-        contents = super().dumps()
-        contents["name"] = self.name
-        return contents
+        return self._dumps()
 
 
 class Tag(_NamedCommit):
@@ -254,12 +256,17 @@ class Tag(_NamedCommit):
         name: The name of the tag.
         commit_id: The commit id.
         parent_commit_id: The parent commit id.
-        message: The commit message.
+        title: The commit title.
+        description: The commit description.
         committer: The commit user.
 
     """
 
 
+_ERROR_MESSAGE = "The '{attr_name}' is not available due to this branch has no commit history."
+_attr = partial(attr, is_dynamic=True, error_message=_ERROR_MESSAGE)
+
+
 class Branch(_NamedCommit):
     """This class defines the structure of a branch.
 
@@ -267,18 +274,37 @@ class Branch(_NamedCommit):
         name: The name of the branch.
         commit_id: The commit id.
         parent_commit_id: The parent commit id.
-        message: The commit message.
+        title: The commit title.
+        description: The commit description.
         committer: The commit user.
 
     """
 
+    parent_commit_id: Optional[str] = _attr(key=camel)
+    title: str = _attr()
+    description: str = _attr()
+    committer: User = _attr()
 
-class Draft(ReprMixin, EqMixin):
+    def _loads(self, contents: Dict[str, Any]) -> None:
+        self.name = contents["name"]
+        self.commit_id = contents["commitId"]
+
+        if self.commit_id == ROOT_COMMIT_ID:
+            return
+
+        self.parent_commit_id = contents["parentCommitId"]
+        self.title = contents["title"]
+        self.description = contents["description"]
+        self.committer = User.loads(contents["committer"])
+
+
+class Draft(AttrsMixin, ReprMixin):
     """This class defines the basic structure of a draft.
 
     Arguments:
         number: The number of the draft.
         title: The title of the draft.
+        branch_name: The branch name.
 
     """
 
@@ -286,17 +312,18 @@ class Draft(ReprMixin, EqMixin):
 
     _repr_attrs = ("title",)
 
-    def __init__(self, number: int, title: str) -> None:
+    number: int = attr()
+    title: str = attr()
+    branch_name: str = attr(key=camel)
+
+    def __init__(self, number: int, title: str, branch_name: str) -> None:
         self.number = number
         self.title = title
+        self.branch_name = branch_name
 
     def _repr_head(self) -> str:
         return f"{self.__class__.__name__}({self.number})"
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self.number = contents["number"]
-        self.title = contents["title"]
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a :class:`Draft` instance from the given contents.
@@ -307,6 +334,7 @@ class Draft(ReprMixin, EqMixin):
                     {
                         "number": <int>
                         "title": <str>
+                        "branchName": <str>
                     }
 
         Returns:
@@ -324,7 +352,8 @@ class Draft(ReprMixin, EqMixin):
                 {
                     "number": <int>
                     "title": <str>
+                    "branchName": <str>
                 }
 
         """
-        return {"number": self.number, "title": self.title}
+        return self._dumps()
