@@ -20,10 +20,10 @@ from urllib.request import urlopen
 from _io import BufferedReader
 
 from ..label import Label
-from ..utility import ReprMixin, ReprType, common_loads
+from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads
 
 
-class DataBase(ReprMixin):  # pylint: disable=too-few-public-methods
+class DataBase(AttrsMixin, ReprMixin):  # pylint: disable=too-few-public-methods
     """DataBase is a base class for the file and label combination.
 
     Arguments:
@@ -46,6 +46,9 @@ class DataBase(ReprMixin):  # pylint: disable=too-few-public-methods
 
     _PATH_KEY = ""
 
+    timestamp: float = attr(is_dynamic=True)
+    label: Label = attr()
+
     def __init__(self, path: str, *, timestamp: Optional[float] = None) -> None:
         self.path = path
         if timestamp is not None:
@@ -56,23 +59,6 @@ class DataBase(ReprMixin):  # pylint: disable=too-few-public-methods
     def _repr_head(self) -> str:
         return f'{self.__class__.__name__}("{self.path}")'
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self.path = contents[self._PATH_KEY]
-        if "timestamp" in contents:
-            self.timestamp = contents["timestamp"]
-
-        self.label = Label.loads(contents["label"])
-
-    def _dumps(self) -> Dict[str, Any]:
-        contents: Dict[str, Any] = {self._PATH_KEY: self.path}
-
-        if hasattr(self, "timestamp"):
-            contents["timestamp"] = self.timestamp
-
-        contents["label"] = self.label.dumps()
-
-        return contents
-
     @staticmethod
     def loads(contents: Dict[str, Any]) -> "_Type":
         """Loads :class:`Data` or :class:`RemoteData` from a dict containing data information.
@@ -126,6 +112,7 @@ class Data(DataBase):
     _T = TypeVar("_T", bound="Data")
 
     _PATH_KEY = "localPath"
+    path: str = attr(key=_PATH_KEY)
 
     def __init__(
         self,
@@ -242,6 +229,7 @@ class RemoteData(DataBase):
     _T = TypeVar("_T", bound="RemoteData")
 
     _PATH_KEY = "remotePath"
+    path: str = attr(key=_PATH_KEY)
 
     def __init__(
         self,
