@@ -15,7 +15,7 @@ which is often used for CV tasks such as lane detection.
 from typing import Any, Dict, Iterable, Optional, Type, TypeVar
 
 from ..geometry import Polyline2D
-from ..utility import ReprType, SubcatalogTypeRegister, TypeRegister, common_loads
+from ..utility import ReprType, SubcatalogTypeRegister, TypeRegister, attr_base, common_loads
 from .basic import LabelType, SubcatalogBase, _LabelBase
 from .supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
 
@@ -33,12 +33,12 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
     Attributes:
         description: The description of the entire 2D polyline subcatalog.
         categories: All the possible categories in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NamedList`
             with the category names as keys
             and the :class:`~tensorbay.label.supports.CategoryInfo` as values.
         category_delimiter: The delimiter in category values indicating parent-child relationship.
         attributes: All the possible attributes in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NamedList`
             with the attribute names as keys
             and the :class:`~tensorbay.label.attribute.AttributeInfo` as values.
         is_tracking: Whether the Subcatalog contains tracking information.
@@ -56,17 +56,17 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
         >>> Polyline2DSubcatalog.loads(catalog["POLYLINE2D"])
         Polyline2DSubcatalog(
           (is_tracking): True,
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NamedList [...],
+          (attributes): NamedList [...]
         )
 
         *Initialization Method 2:* Init an empty Polyline2DSubcatalog and then add the attributes.
 
         >>> from tensorbay.label import CategoryInfo, AttributeInfo
-        >>> from tensorbay.utility import NameOrderedDict
-        >>> categories = NameOrderedDict()
+        >>> from tensorbay.utility import NamedList
+        >>> categories = NamedList()
         >>> categories.append(CategoryInfo("a"))
-        >>> attributes = NameOrderedDict()
+        >>> attributes = NamedList()
         >>> attributes.append(AttributeInfo("gender", enum=["female", "male"]))
         >>> polyline2d_subcatalog = Polyline2DSubcatalog()
         >>> polyline2d_subcatalog.is_tracking = True
@@ -75,18 +75,19 @@ class Polyline2DSubcatalog(  # pylint: disable=too-many-ancestors
         >>> polyline2d_subcatalog
         Polyline2DSubcatalog(
           (is_tracking): True,
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NamedList [...],
+          (attributes): NamedList [...]
         )
 
     """
 
     def __init__(self, is_tracking: bool = False) -> None:
+        SubcatalogBase.__init__(self)
         IsTrackingMixin.__init__(self, is_tracking)
 
 
 @TypeRegister(LabelType.POLYLINE2D)
-class LabeledPolyline2D(Polyline2D, _LabelBase):  # pylint: disable=too-many-ancestors
+class LabeledPolyline2D(_LabelBase, Polyline2D):  # pylint: disable=too-many-ancestors
     """This class defines the concept of polyline2D label.
 
     :class:`LabeledPolyline2D` is the 2D polyline type of label,
@@ -126,6 +127,7 @@ class LabeledPolyline2D(Polyline2D, _LabelBase):  # pylint: disable=too-many-anc
 
     _repr_type = ReprType.SEQUENCE
     _repr_attrs = _LabelBase._repr_attrs
+    _attrs_base: Polyline2D = attr_base(key="polyline2d")
 
     def __init__(
         self,
@@ -135,13 +137,9 @@ class LabeledPolyline2D(Polyline2D, _LabelBase):  # pylint: disable=too-many-anc
         attributes: Optional[Dict[str, Any]] = None,
         instance: Optional[str] = None,
     ):
-        super().__init__(points)
+        Polyline2D.__init__(self, points)  # type: ignore[arg-type]
         _LabelBase.__init__(self, category, attributes, instance)
 
-    def _loads(self, contents: Dict[str, Any]) -> None:  # type: ignore[override]
-        super()._loads(contents["polyline2d"])
-        _LabelBase._loads(self, contents)
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:  # type: ignore[override]
         """Loads a LabeledPolyline2D from a dict containing the information of the label.
@@ -195,7 +193,4 @@ class LabeledPolyline2D(Polyline2D, _LabelBase):  # pylint: disable=too-many-anc
             }
 
         """
-        contents = _LabelBase.dumps(self)
-        contents["polyline2d"] = super().dumps()
-
-        return contents
+        return self._dumps()
