@@ -27,10 +27,10 @@ from typing import Dict, Iterator, Optional, Sequence, Tuple, Type, TypeVar
 import numpy as np
 
 from ..geometry import Vector2D
-from ..utility import MatrixType, ReprMixin, ReprType, common_loads
+from ..utility import AttrsMixin, MatrixType, ReprMixin, ReprType, attr, camel, common_loads
 
 
-class CameraMatrix(ReprMixin):
+class CameraMatrix(ReprMixin, AttrsMixin):
     """CameraMatrix represents camera matrix.
 
     Camera matrix describes the mapping of a pinhole camera model from 3D points in the world
@@ -97,6 +97,12 @@ class CameraMatrix(ReprMixin):
     _repr_type = ReprType.INSTANCE
     _repr_attrs = ("fx", "fy", "cx", "cy", "skew")
 
+    fx: float = attr()
+    fy: float = attr()
+    cx: float = attr()
+    cy: float = attr()
+    skew: float = attr(default=0)
+
     def __init__(  # pylint: disable=too-many-arguments
         self,
         fx: Optional[float] = None,
@@ -128,25 +134,6 @@ class CameraMatrix(ReprMixin):
             f"Require 'fx', 'fy', 'cx', 'cy' or 3x3 matrix to initialize {self.__class__.__name__}"
         )
 
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, self.__class__):
-            return False
-
-        return (
-            self.fx == other.fx
-            and self.fy == other.fy
-            and self.cx == other.cx
-            and self.cy == other.cy
-            and self.skew == other.skew
-        )
-
-    def _loads(self, contents: Dict[str, float]) -> None:
-        self.fx = contents["fx"]
-        self.fy = contents["fy"]
-        self.cx = contents["cx"]
-        self.cy = contents["cy"]
-        self.skew = contents.get("skew", 0)
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, float]) -> _T:
         """Loads CameraMatrix from a dict containing the information of the camera matrix.
@@ -189,13 +176,7 @@ class CameraMatrix(ReprMixin):
             {'fx': 1, 'fy': 2, 'cx': 3, 'cy': 4, 'skew': 3}
 
         """
-        return {
-            "fx": self.fx,
-            "fy": self.fy,
-            "cx": self.cx,
-            "cy": self.cy,
-            "skew": self.skew,
-        }
+        return self._dumps()
 
     def as_matrix(self) -> np.ndarray:
         """Return the camera matrix as a 3x3 numpy array.
@@ -257,7 +238,7 @@ class CameraMatrix(ReprMixin):
         return Vector2D(x, y)
 
 
-class DistortionCoefficients(ReprMixin):
+class DistortionCoefficients(ReprMixin, AttrsMixin):
     """DistortionCoefficients represents camera distortion coefficients.
 
     Distortion is the deviation from rectilinear projection including radial distortion
@@ -296,16 +277,6 @@ class DistortionCoefficients(ReprMixin):
                 f"Require tangential or radial distortion to initialize {self.__class__.__name__}"
             )
 
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, self.__class__):
-            return False
-
-        for key in self._DISTORTION_KEYS:
-            if tuple(self._list_distortions(key)) != tuple(other._list_distortions(key)):
-                return False
-
-        return True
-
     @staticmethod
     def _distortion_generator(
         distortion_keyword: str, data: Dict[str, float]
@@ -475,7 +446,7 @@ class DistortionCoefficients(ReprMixin):
         return Vector2D(x, y)
 
 
-class CameraIntrinsics(ReprMixin):
+class CameraIntrinsics(ReprMixin, AttrsMixin):
     """CameraIntrinsics represents camera intrinsics.
 
     Camera intrinsic parameters including camera matrix and distortion coeffecients.
@@ -554,6 +525,9 @@ class CameraIntrinsics(ReprMixin):
     _repr_attrs = ("camera_matrix", "distortion_coefficients")
     _repr_maxlevel = 2
 
+    camera_matrix: CameraMatrix = attr(key=camel)
+    distortion_coefficients: DistortionCoefficients = attr(is_dynamic=True, key=camel)
+
     def __init__(  # pylint: disable=too-many-arguments
         self,
         fx: Optional[float] = None,
@@ -565,26 +539,9 @@ class CameraIntrinsics(ReprMixin):
         camera_matrix: Optional[MatrixType] = None,
         **kwargs: float,
     ) -> None:
-        self._camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=camera_matrix)
-        self._distortion_coefficients = DistortionCoefficients.loads(kwargs) if kwargs else None
-
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, self.__class__):
-            return False
-
-        return (
-            self.camera_matrix == other.camera_matrix
-            and self.distortion_coefficients == other.distortion_coefficients
-        )
-
-    def _loads(self, contents: Dict[str, Dict[str, float]]) -> None:
-        self._camera_matrix = CameraMatrix.loads(contents["cameraMatrix"])
-        if "distortionCoefficients" in contents:
-            self._distortion_coefficients = DistortionCoefficients.loads(
-                contents["distortionCoefficients"]
-            )
-        else:
-            self._distortion_coefficients = None
+        self.camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=camera_matrix)
+        if kwargs:
+            self.distortion_coefficients = DistortionCoefficients.loads(kwargs)
 
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Dict[str, float]]) -> _T:
@@ -633,44 +590,6 @@ class CameraIntrinsics(ReprMixin):
         """
         return common_loads(cls, contents)
 
-    @property
-    def camera_matrix(self) -> CameraMatrix:
-        """Get the camera matrix of the camera intrinsics.
-
-        Returns:
-            :class:`CameraMatrix` class object containing fx, fy, cx, cy, skew(optional).
-
-        Examples:
-            >>> camera_intrinsics.camera_matrix
-            CameraMatrix(
-                (fx): 1,
-                (fy): 2,
-                (cx): 3,
-                (cy): 4,
-                (skew): 3
-            )
-
-        """
-        return self._camera_matrix
-
-    @property
-    def distortion_coefficients(self) -> Optional[DistortionCoefficients]:
-        """Get the distortion coefficients of the camera intrinsics, could be None.
-
-        Returns:
-            :class:`DistortionCoefficients` class object containing tangential and
-            radial distortion coefficients.
-
-        Examples:
-            >>> camera_intrinsics.distortion_coefficients
-            DistortionCoefficients(
-                (p1): 5,
-                (k1): 6
-            )
-
-        """
-        return self._distortion_coefficients
-
     def dumps(self) -> Dict[str, Dict[str, float]]:
         """Dumps the camera intrinsics into a dict.
 
@@ -683,11 +602,7 @@ class CameraIntrinsics(ReprMixin):
             'distortionCoefficients': {'p1': 5, 'k1': 6}}
 
         """
-        contents = {"cameraMatrix": self._camera_matrix.dumps()}
-        if self._distortion_coefficients:
-            contents["distortionCoefficients"] = self._distortion_coefficients.dumps()
-
-        return contents
+        return self._dumps()
 
     def set_camera_matrix(  # pylint: disable=[too-many-arguments, invalid-name]
         self,
@@ -731,7 +646,7 @@ class CameraIntrinsics(ReprMixin):
             )
 
         """
-        self._camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=matrix)
+        self.camera_matrix = CameraMatrix(fx, fy, cx, cy, skew, matrix=matrix)
 
     def set_distortion_coefficients(self, **kwargs: float) -> None:
         """Set distortion coefficients of the camera intrinsics.
@@ -759,7 +674,7 @@ class CameraIntrinsics(ReprMixin):
             )
 
         """
-        self._distortion_coefficients = DistortionCoefficients(**kwargs)
+        self.distortion_coefficients = DistortionCoefficients(**kwargs)
 
     def project(self, point: Sequence[float], is_fisheye: bool = False) -> Vector2D:
         """Project a point to the pixel coordinates.
@@ -790,6 +705,6 @@ class CameraIntrinsics(ReprMixin):
             Vector2D(9.158401093771875, 28.633604375087504)
 
         """
-        if self._distortion_coefficients:
-            point = self._distortion_coefficients.distort(point, is_fisheye)
-        return self._camera_matrix.project(point)
+        if hasattr(self, "distortion_coefficients"):
+            point = self.distortion_coefficients.distort(point, is_fisheye)
+        return self.camera_matrix.project(point)
