@@ -5,27 +5,37 @@
 
 """Utility classes."""
 
-from .common import Deprecated, EqMixin, KwargsDeprecated, MatrixType, common_loads, locked
-from .name import NameMixin, NameOrderedDict, NameSortedDict, NameSortedList
+from .attr import AttrsMixin, attr, attr_base, camel, upper
+from .common import (
+    DefaultValueDeprecated,
+    Deprecated,
+    Disable,
+    EqMixin,
+    KwargsDeprecated,
+    MatrixType,
+    common_loads,
+    locked,
+)
+from .name import NamedList, NameMixin, NameSortedDict, NameSortedList
 from .repr import ReprMixin, ReprType, repr_config
-from .tbrn import TBRN, TBRNType
 from .type import SubcatalogTypeRegister, TypeEnum, TypeMixin, TypeRegister
 from .user import UserMapping, UserMutableMapping, UserMutableSequence, UserSequence
 
 __all__ = [
+    "AttrsMixin",
+    "DefaultValueDeprecated",
     "Deprecated",
     "EqMixin",
+    "Disable",
     "KwargsDeprecated",
     "MatrixType",
     "NameMixin",
-    "NameOrderedDict",
     "NameSortedDict",
     "NameSortedList",
+    "NamedList",
     "ReprMixin",
     "ReprType",
     "SubcatalogTypeRegister",
-    "TBRN",
-    "TBRNType",
     "TypeEnum",
     "TypeMixin",
     "TypeRegister",
@@ -33,7 +43,11 @@ __all__ = [
     "UserMutableMapping",
     "UserMutableSequence",
     "UserSequence",
+    "attr",
+    "attr_base",
+    "camel",
     "common_loads",
     "locked",
     "repr_config",
+    "upper",
 ]
