@@ -6,8 +6,10 @@
 import pytest
 
 from tensorbay import GAS, __version__
+from tensorbay.client.gas import DEFAULT_BRANCH
+from tensorbay.client.struct import ROOT_COMMIT_ID
 from tensorbay.dataset import Data, Segment
-from tensorbay.exception import CommitStatusError, ResourceNotExistError
+from tensorbay.exception import ResourceNotExistError, StatusError
 
 from .utility import get_dataset_name
 
@@ -18,23 +20,27 @@ class TestCommit:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
         dataset_client.create_draft("draft-1")
-        dataset_client.commit("commit-1", tag="V1")
+        dataset_client.commit("commit-1", "test", tag="V1")
         commit_1_id = dataset_client.status.commit_id
         dataset_client.create_draft("draft-2")
         dataset_client.commit("commit-2")
         commit_2_id = dataset_client.status.commit_id
 
-        commit = dataset_client.get_commit(commit_1_id)
-        assert commit.commit_id == commit_1_id
-        assert commit.parent_commit_id is None
-        assert commit.message == "commit-1"
-        assert commit.committer.name
-        assert commit.committer.date
-
+        # Get top commit
         commit = dataset_client.get_commit(commit_2_id)
         assert commit.commit_id == commit_2_id
         assert commit.parent_commit_id == commit_1_id
-        assert commit.message == "commit-2"
+        assert commit.title == "commit-2"
+        assert commit.description == ""
+        assert commit.committer.name
+        assert commit.committer.date
+
+        # Get one commit before the top one
+        commit = dataset_client.get_commit(commit_1_id)
+        assert commit.commit_id == commit_1_id
+        assert commit.parent_commit_id == ROOT_COMMIT_ID
+        assert commit.title == "commit-1"
+        assert commit.description == "test"
         assert commit.committer.name
         assert commit.committer.date
 
@@ -42,13 +48,14 @@ class TestCommit:
         commit = dataset_client.get_commit()
         assert commit.commit_id == commit_2_id
         assert commit.parent_commit_id == commit_1_id
-        assert commit.message == "commit-2"
+        assert commit.title == "commit-2"
+        assert commit.description == ""
         assert commit.committer.name
         assert commit.committer.date
 
         # Can not create the tag without giving commit in the draft
         dataset_client.create_draft("draft-3")
-        with pytest.raises(CommitStatusError):
+        with pytest.raises(StatusError):
             dataset_client.get_commit()
 
         gas_client.delete_dataset(dataset_name)
@@ -58,23 +65,27 @@ class TestCommit:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
         dataset_client.create_draft("draft-1")
-        dataset_client.commit("commit-1", tag="V1")
+        dataset_client.commit("commit-1", "test", tag="V1")
         commit_1_id = dataset_client.status.commit_id
         dataset_client.create_draft("draft-2")
         dataset_client.commit("commit-2")
         commit_2_id = dataset_client.status.commit_id
 
+        # Get top commit by tag
         commit = dataset_client.get_commit("V1")
         assert commit.commit_id == commit_1_id
-        assert commit.parent_commit_id is None
-        assert commit.message == "commit-1"
+        assert commit.parent_commit_id == ROOT_COMMIT_ID
+        assert commit.title == "commit-1"
+        assert commit.description == "test"
         assert commit.committer.name
         assert commit.committer.date
 
-        commit = dataset_client.get_commit("main")
+        # Get top commit by branch
+        commit = dataset_client.get_commit(DEFAULT_BRANCH)
         assert commit.commit_id == commit_2_id
         assert commit.parent_commit_id == commit_1_id
-        assert commit.message == "commit-2"
+        assert commit.title == "commit-2"
+        assert commit.description == ""
         assert commit.committer.name
         assert commit.committer.date
 
@@ -100,26 +111,29 @@ class TestCommit:
         dataset_client.commit("commit-3")
         commit_3_id = dataset_client.status.commit_id
 
+        # List commits(based on default branch)
         commits = dataset_client.list_commits()
         assert len(commits) == 3
         assert commits[0].commit_id == commit_3_id
         assert commits[1].commit_id == commit_2_id
 
+        # List commits based on one commit before the top one
         commits = dataset_client.list_commits(commit_2_id)
         assert len(commits) == 2
         assert commits[0].commit_id == commit_2_id
         assert commits[1].commit_id == commit_1_id
 
+        # List commits based on tag
         commits = dataset_client.list_commits("V1")
         assert len(commits) == 1
         assert commits[0].commit_id == commit_1_id
 
-        commits = dataset_client.list_commits("main")
+        # List commits based on default branch
+        commits = dataset_client.list_commits(DEFAULT_BRANCH)
         assert len(commits) == 3
 
         gas_client.delete_dataset(dataset_name)
 
-    @pytest.mark.xfail(__version__ < "1.7.0", reason="not supported at least until v1.7.0")
     def test_data_in_draft(self, accesskey, url, tmp_path):
         gas_client = GAS(access_key=accesskey, url=url)
         dataset_name = get_dataset_name()
