@@ -6,8 +6,9 @@
 import pytest
 
 from tensorbay import GAS
-from tensorbay.exception import CommitStatusError, ResourceNotExistError, ResponseError
-from tensorbay.label import Catalog
+from tensorbay.client.gas import DEFAULT_BRANCH
+from tensorbay.client.struct import ROOT_COMMIT_ID
+from tensorbay.exception import ResourceNotExistError, ResponseError, StatusError
 
 from .utility import get_dataset_name
 
@@ -18,9 +19,10 @@ class TestDataset:
         dataset_name = get_dataset_name()
 
         dataset_client = gas_client.create_dataset(dataset_name)
-        assert dataset_client.status.commit_id is None
+        assert dataset_client.status.commit_id == ROOT_COMMIT_ID
         assert dataset_client.status.draft_number is None
         assert not dataset_client.status.is_draft
+        assert dataset_client.status.branch_name == DEFAULT_BRANCH
         assert dataset_client.name == dataset_name
         assert dataset_client.dataset_id is not None
         gas_client.get_dataset(dataset_name)
@@ -48,9 +50,10 @@ class TestDataset:
         dataset_name = get_dataset_name()
 
         dataset_client = gas_client.create_dataset(dataset_name, is_fusion=True)
-        assert dataset_client.status.commit_id is None
+        assert dataset_client.status.commit_id == ROOT_COMMIT_ID
         assert dataset_client.status.draft_number is None
         assert not dataset_client.status.is_draft
+        assert dataset_client.status.branch_name == DEFAULT_BRANCH
         assert dataset_client._name == dataset_name
         assert dataset_client.dataset_id is not None
         gas_client.get_dataset(dataset_name, is_fusion=True)
@@ -74,9 +77,10 @@ class TestDataset:
         dataset_client.create_draft("v_test")
 
         dataset_client_1 = gas_client.get_dataset(dataset_name)
-        assert dataset_client_1.status.commit_id is None
+        assert dataset_client_1.status.commit_id == ROOT_COMMIT_ID
         assert dataset_client_1.status.draft_number is None
-        assert dataset_client.status.is_draft
+        assert not dataset_client_1.status.is_draft
+        assert dataset_client.status.branch_name == DEFAULT_BRANCH
         assert dataset_client_1.name == dataset_name
         assert dataset_client.dataset_id is not None
 
@@ -87,14 +91,15 @@ class TestDataset:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
         dataset_client.create_draft("v_test_1")
-        dataset_client.commit(message="Test", tag="V1")
+        dataset_client.commit("Test", tag="V1")
         dataset_client.create_draft("v_test_2")
-        dataset_client.commit(message="Test", tag="V2")
+        dataset_client.commit("Test", tag="V2")
         v2_commit_id = dataset_client.status.commit_id
 
         dataset_client = gas_client.get_dataset(dataset_name)
         assert dataset_client.status.commit_id == v2_commit_id
         assert dataset_client.status.draft_number is None
+        assert dataset_client.status.branch_name == DEFAULT_BRANCH
         assert dataset_client.name == dataset_name
         assert dataset_client.dataset_id is not None
 
@@ -105,14 +110,15 @@ class TestDataset:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name, is_fusion=True)
         dataset_client.create_draft("v_test_1")
-        dataset_client.commit(message="Test", tag="V1")
+        dataset_client.commit("Test", tag="V1")
         dataset_client.create_draft("v_test_2")
-        dataset_client.commit(message="Test", tag="V2")
+        dataset_client.commit("Test", tag="V2")
         v2_commit_id = dataset_client.status.commit_id
 
         dataset_client = gas_client.get_dataset(dataset_name, is_fusion=True)
         assert dataset_client.status.commit_id == v2_commit_id
         assert dataset_client.status.draft_number is None
+        assert dataset_client.status.branch_name == DEFAULT_BRANCH
         assert dataset_client.name == dataset_name
         assert dataset_client.dataset_id is not None
 
@@ -123,9 +129,9 @@ class TestDataset:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
         dataset_client.create_draft("v_test")
-        dataset_client.commit(message="Test", tag="V1")
+        dataset_client.commit("Test", tag="V1")
 
-        new_dataset_name = get_dataset_name()
+        new_dataset_name = f"{get_dataset_name()}new"
         gas_client.rename_dataset(name=dataset_name, new_name=new_dataset_name)
         with pytest.raises(ResourceNotExistError):
             gas_client.get_dataset(dataset_name)
@@ -145,7 +151,7 @@ class TestDataset:
         dataset_name_2 = get_dataset_name()
         dataset_client_2 = gas_client.create_dataset(dataset_name_2)
         dataset_client_2.create_draft("v_test")
-        dataset_client_2.commit(message="Test", tag="V1")
+        dataset_client_2.commit("Test", tag="V1")
         gas_client.delete_dataset(dataset_name_2)
         with pytest.raises(ResourceNotExistError):
             gas_client.get_dataset(dataset_name_2)
@@ -160,21 +166,24 @@ class TestDataset:
         dataset_client.create_draft("draft-2")
         dataset_client.commit("commit-2")
         commit_2_id = dataset_client.status.commit_id
-        # Neither commit key nor draft number is given
+        # Neither revision nor draft number is given
         with pytest.raises(TypeError):
             dataset_client.checkout()
-        # Both commit key and draft number are given
+        # Both revision and draft number are given
         with pytest.raises(TypeError):
             dataset_client.checkout(revision=commit_1_id, draft_number=3)
         dataset_client.checkout(revision=commit_1_id)
+        assert dataset_client._status.branch_name is None
         assert dataset_client._status.commit_id == commit_1_id
-        # The commit does not exist.
+        # The revision does not exist.
         with pytest.raises(ResourceNotExistError):
             dataset_client.checkout(revision="123")
         assert dataset_client._status.commit_id == commit_1_id
         dataset_client.checkout(revision="V1")
+        assert dataset_client._status.branch_name is None
         assert dataset_client._status.commit_id == commit_1_id
-        dataset_client.checkout(revision="main")
+        dataset_client.checkout(revision=DEFAULT_BRANCH)
+        assert dataset_client._status.branch_name == DEFAULT_BRANCH
         assert dataset_client._status.commit_id == commit_2_id
 
         dataset_client.create_draft("draft-3")
@@ -182,6 +191,7 @@ class TestDataset:
         with pytest.raises(ResourceNotExistError):
             dataset_client.checkout(draft_number=2)
         dataset_client.checkout(draft_number=3)
+        assert dataset_client._status.branch_name == DEFAULT_BRANCH
         assert dataset_client._status.draft_number == 3
 
         gas_client.delete_dataset(dataset_name)
@@ -191,7 +201,7 @@ class TestDataset:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
 
-        with pytest.raises(CommitStatusError):
+        with pytest.raises(StatusError):
             dataset_client.update_notes(is_continuous=True)
         dataset_client.create_draft("draft-1")
         notes_1 = dataset_client.get_notes()
