@@ -6,8 +6,9 @@
 import pytest
 
 from tensorbay.client import GAS
+from tensorbay.client.gas import DEFAULT_BRANCH
 from tensorbay.client.struct import Draft
-from tensorbay.exception import CommitStatusError, ResponseError
+from tensorbay.exception import ResponseError, StatusError
 
 from .utility import get_dataset_name, get_draft_number_by_title
 
@@ -23,7 +24,7 @@ class TestDraft:
         assert dataset_client.status.is_draft
         assert dataset_client.status.draft_number == draft_number_1
         assert dataset_client.status.commit_id is None
-        with pytest.raises(CommitStatusError):
+        with pytest.raises(StatusError):
             dataset_client.create_draft("draft-2")
         draft_number = get_draft_number_by_title(dataset_client.list_drafts(), "draft-1")
         assert draft_number_1 == draft_number
@@ -35,7 +36,7 @@ class TestDraft:
         dataset_name = get_dataset_name()
         dataset_client = gas_client.create_dataset(dataset_name)
         dataset_client.create_draft("draft-1")
-        dataset_client.commit(message="commit-draft-1")
+        dataset_client.commit("commit-draft-1")
         draft_number_2 = dataset_client.create_draft("draft-2")
 
         # After committing, the draft will be deleted
@@ -44,7 +45,7 @@ class TestDraft:
 
         drafts = dataset_client.list_drafts()
         assert len(drafts) == 1
-        assert drafts[0] == Draft(draft_number_2, "draft-2")
+        assert drafts[0] == Draft(draft_number_2, "draft-2", DEFAULT_BRANCH)
 
         with pytest.raises(TypeError):
             get_draft_number_by_title(dataset_client.list_drafts(), "draft-3")
